@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} bitunpack (@var{X})
 ## @comment DO NOT SYNCHRONIZE DOCUMENTATION STRING
 ## 
@@ -50,11 +50,7 @@ if (isnai (x))
 endif
 
 bare = bitunpack (intervalpart (x));
-d = bitunpack (uint8 (...
-        strcmp (x.dec, 'trv') * 4 + ...
-        strcmp (x.dec, 'def') * 8 + ...
-        strcmp (x.dec, 'dac') * 12 + ...
-        strcmp (x.dec, 'com') * 16));
+d = bitunpack (x.dec);
 
 ## Initialize result vector
 result = zeros (1, length (bare) + length (d), 'logical');
