@@ -24,9 +24,9 @@
 ## @example
 ## @group
 ## floor (infsupdec (2.5, 3.5))
-##   @result{} [2, 3]_def
+##   @result{} ans = [2, 3]_def
 ## floor (infsupdec (-0.5, 5))
-##   @result{} [-1, +5]_def
+##   @result{} ans = [-1, +5]_def
 ## @end group
 ## @end example
 ## @seealso{@@infsupdec/ceil, @@infsupdec/round, @@infsupdec/roundb, @@infsupdec/fix}
